## ---- eval=FALSE--------------------------------------------------------------
#  if (!requireNamespace("BiocManager", quietly = TRUE))
#      install.packages("BiocManager")
#  
#  BiocManager::install("curatedTCGAData")

## ----include=TRUE,results="hide",message=FALSE,warning=FALSE------------------
library(curatedTCGAData)
library(MultiAssayExperiment)
library(TCGAutils)

## -----------------------------------------------------------------------------
curatedTCGAData(diseaseCode = "*", assays = "*", dry.run = TRUE)

## -----------------------------------------------------------------------------
curatedTCGAData(diseaseCode = "COAD", assays = "RPPA*", dry.run = TRUE)

## ---- message=FALSE-----------------------------------------------------------
(accmae <- curatedTCGAData("ACC", c("CN*", "Mutation"), FALSE))

## -----------------------------------------------------------------------------
head(getSubtypeMap(accmae))

## -----------------------------------------------------------------------------
head(getClinicalNames("ACC"))

colData(accmae)[, getClinicalNames("ACC")][1:5, 1:5]

## -----------------------------------------------------------------------------
sampleTables(accmae)

## -----------------------------------------------------------------------------
sampleTypes[sampleTypes[["Code"]] %in% c("01", "10"), ]

splitAssays(accmae, c("01", "10"))

## -----------------------------------------------------------------------------
tums <- TCGAsampleSelect(colnames(accmae), "01")

## -----------------------------------------------------------------------------
accmae[, tums, ]

## -----------------------------------------------------------------------------
td <- tempdir()
tempd <- file.path(td, "ACCMAE")
if (!dir.exists(tempd))
    dir.create(tempd)

exportClass(accmae, dir = tempd, fmt = "csv", ext = ".csv")

## -----------------------------------------------------------------------------
sessionInfo()

